==> ice-3.7.5.tgz: package/src/es5/Ice/StreamHelpers.js <==
"use strict";

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _createForOfIteratorHelper(o, allowArrayLike) { var it; if (typeof Symbol === "undefined" || o[Symbol.iterator] == null) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e2) { throw _e2; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = o[Symbol.iterator](); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e3) { didErr = true; err = _e3; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

//
// Copyright (c) ZeroC, Inc. All rights reserved.
//
var Ice = require("../Ice/OptionalFormat").Ice;

var defineProperty = Object.defineProperty;
var OptionalFormat = Ice.OptionalFormat;
var StreamHelpers = {};

StreamHelpers.FSizeOptHelper = function () {
  this.writeOptional = function (os, tag, v) {
    if (v !== undefined && os.writeOptional(tag, OptionalFormat.FSize)) {
      var pos = os.startSize();
      this.write(os, v);
      os.endSize(pos);
    }
  };

  this.readOptional = function (is, tag) {
    var v;

    if (is.readOptional(tag, OptionalFormat.FSize)) {
      is.skip(4);
      v = this.read(is);
    }

    return v;
  };
};

StreamHelpers.VSizeOptHelper = function () {
  this.writeOptional = function (os, tag, v) {
    if (v !== undefined && os.writeOptional(tag, OptionalFormat.VSize)) {
      os.writeSize(this.minWireSize);
      this.write(os, v);
    }
  };

  this.readOptional = function (is, tag) {
    var v;

    if (is.readOptional(tag, OptionalFormat.VSize)) {
      is.skipSize();
      v = this.read(is);
    }

    return v;
  };
};

StreamHelpers.VSizeContainerOptHelper = function (elementSize) {
  this.writeOptional = function (os, tag, v) {
    if (v !== undefined && os.writeOptional(tag, OptionalFormat.VSize)) {
      var sz = this.size(v);
      os.writeSize(sz > 254 ? sz * elementSize + 5 : sz * elementSize + 1);
      this.write(os, v);
    }
  };

  this.readOptional = function (is, tag) {
    var v;

    if (is.readOptional(tag, OptionalFormat.VSize)) {
      is.skipSize();
      v = this.read(is);
    }

    return v;
  };
};

StreamHelpers.VSizeContainer1OptHelper = function () {
  this.writeOptional = function (os, tag, v) {
    if (v !== undefined && os.writeOptional(tag, OptionalFormat.VSize)) {
      this.write(os, v);
    }
  };

  this.readOptional = function (is, tag) {
    var v;

    if (is.readOptional(tag, OptionalFormat.VSize)) {
      v = this.read(is);
    }

    return v;
  };
}; //
// Sequence helper to write sequences
//


var SequenceHelper = /*#__PURE__*/function () {
  function SequenceHelper() {
    _classCallCheck(this, SequenceHelper);
  }

  _createClass(SequenceHelper, [{
    key: "write",
    value: function write(os, v) {
      if (v === null || v === undefined || v.length === 0) {
        os.writeSize(0);
      } else {
        var helper = this.elementHelper;
        os.writeSize(v.length);

        for (var i = 0; i < v.length; ++i) {
          helper.write(os, v[i]);
        }
      }
    }
  }, {
    key: "read",
    value: function read(is) {
      var helper = this.elementHelper; // Cache the element helper.

      var sz = is.readAndCheckSeqSize(helper.minWireSize);
      var v = [];
      v.length = sz;

      for (var i = 0; i < sz; ++i) {
        v[i] = helper.read(is);
      }

      return v;
    }
  }, {
    key: "size",
    value: function size(v) {
      return v === null || v === undefined ? 0 : v.length;
    }
  }, {
    key: "minWireSize",
    get: function get() {
      return 1;
    }
  }]);

  return SequenceHelper;
}(); // Speacialization optimized for ByteSeq


var byteSeqHelper = new SequenceHelper();

byteSeqHelper.write = function (os, v) {
  return os.writeByteSeq(v);
};

byteSeqHelper.read = function (is) {
  return is.readByteSeq();
};

defineProperty(byteSeqHelper, "elementHelper", {
  get: function get() {
    return Ice.ByteHelper;
  }
});
StreamHelpers.VSizeContainer1OptHelper.call(byteSeqHelper); // Read method for value sequences

var valueSequenceHelperRead = function valueSequenceHelperRead(is) {
  var sz = is.readAndCheckSeqSize(1);
  var v = [];
  v.length = sz;
  var elementType = this.elementType;

  var readValueAtIndex = function readValueAtIndex(idx) {
    is.readValue(function (obj) {
      v[idx] = obj;
    }, elementType);
  };

  for (var i = 0; i < sz; ++i) {
    readValueAtIndex(i);
  }

  return v;
};

StreamHelpers.generateSeqHelper = function (elementHelper, fixed, elementType) {
  if (elementHelper === Ice.ByteHelper) {
    return byteSeqHelper;
  }

  var helper = new SequenceHelper();

  if (fixed) {
    if (elementHelper.minWireSize === 1) {
      StreamHelpers.VSizeContainer1OptHelper.call(helper);
    } else {
      StreamHelpers.VSizeContainerOptHelper.call(helper, elementHelper.minWireSize);
    }
  } else {
    StreamHelpers.FSizeOptHelper.call(helper);
  }

  defineProperty(helper, "elementHelper", {
    get: function get() {
      return elementHelper;
    }
  });

  if (elementHelper == Ice.ObjectHelper) {
    defineProperty(helper, "elementType", {
      get: function get() {
        return elementType;
      }
    });
    helper.read = valueSequenceHelperRead;
  }

  return helper;
}; //
// Dictionary helper to write dictionaries
//


var DictionaryHelper = /*#__PURE__*/function () {
  function DictionaryHelper() {
    _classCallCheck(this, DictionaryHelper);
  }

  _createClass(DictionaryHelper, [{
    key: "write",
    value: function write(os, v) {
      if (v === null || v == undefined || v.size === 0) {
        os.writeSize(0);
      } else {
        var keyHelper = this.keyHelper;
        var valueHelper = this.valueHelper;
        os.writeSize(v.size);

        var _iterator = _createForOfIteratorHelper(v),
            _step;

        try {
          for (_iterator.s(); !(_step = _iterator.n()).done;) {
            var _step$value = _slicedToArray(_step.value, 2),
                key = _step$value[0],
                value = _step$value[1];

            keyHelper.write(os, key);
            valueHelper.write(os, value);
          }
        } catch (err) {
          _iterator.e(err);
        } finally {
          _iterator.f();
        }
      }
    }
  }, {
    key: "read",
    value: function read(is) {
      var mapType = this.mapType;
      var v = new mapType();
      var sz = is.readSize();
      var keyHelper = this.keyHelper;
      var valueHelper = this.valueHelper;

      for (var i = 0; i < sz; ++i) {
        v.set(keyHelper.read(is), valueHelper.read(is));
      }

      return v;
    }
  }, {
    key: "size",
    value: function size(v) {
      return v === null || v === undefined ? 0 : v.size;
    }
  }, {
    key: "minWireSize",
    get: function get() {
      return 1;
    }
  }]);

  return DictionaryHelper;
}(); // Read method for dictionaries of values


var valueDictionaryHelperRead = function valueDictionaryHelperRead(is) {
  var sz = is.readSize();
  var mapType = this.mapType;
  var v = new mapType();
  var valueType = this.valueType;

  var readValueForKey = function readValueForKey(key) {
    is.readValue(function (obj) {
      return v.set(key, obj);
    }, valueType);
  };

  var keyHelper = this.keyHelper;

  for (var i = 0; i < sz; ++i) {
    readValueForKey(keyHelper.read(is));
  }

  return v;
};

StreamHelpers.generateDictHelper = function (keyHelper, valueHelper, fixed, valueType, mapType) {
  var helper = new DictionaryHelper();

  if (fixed) {
    StreamHelpers.VSizeContainerOptHelper.call(helper, keyHelper.minWireSize + valueHelper.minWireSize);
  } else {
    StreamHelpers.FSizeOptHelper.call(helper);
  }

  defineProperty(helper, "mapType", {
    get: function get() {
      return mapType;
    }
  });
  defineProperty(helper, "keyHelper", {
    get: function get() {
      return keyHelper;
    }
  });
  defineProperty(helper, "valueHelper", {
    get: function get() {
      return valueHelper;
    }
  });

  if (valueHelper == Ice.ObjectHelper) {
    defineProperty(helper, "valueType", {
      get: function get() {
        return valueType;
      }
    });
    helper.read = valueDictionaryHelperRead;
  }

  return helper;
};

Ice.StreamHelpers = StreamHelpers;
module.exports.Ice = Ice;

==> ice-3.7.70.tgz: package/src/es5/Ice/StreamHelpers.js <==
"use strict";

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e2) { throw _e2; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e3) { didErr = true; err = _e3; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

//
// Copyright (c) ZeroC, Inc. All rights reserved.
//
var Ice = require("../Ice/OptionalFormat").Ice;

var defineProperty = Object.defineProperty;
var OptionalFormat = Ice.OptionalFormat;
var StreamHelpers = {};

StreamHelpers.FSizeOptHelper = function () {
  this.writeOptional = function (os, tag, v) {
    if (v !== undefined && os.writeOptional(tag, OptionalFormat.FSize)) {
      var pos = os.startSize();
      this.write(os, v);
      os.endSize(pos);
    }
  };

  this.readOptional = function (is, tag) {
    var v;

    if (is.readOptional(tag, OptionalFormat.FSize)) {
      is.skip(4);
      v = this.read(is);
    }

    return v;
  };
};

StreamHelpers.VSizeOptHelper = function () {
  this.writeOptional = function (os, tag, v) {
    if (v !== undefined && os.writeOptional(tag, OptionalFormat.VSize)) {
      os.writeSize(this.minWireSize);
      this.write(os, v);
    }
  };

  this.readOptional = function (is, tag) {
    var v;

    if (is.readOptional(tag, OptionalFormat.VSize)) {
      is.skipSize();
      v = this.read(is);
    }

    return v;
  };
};

StreamHelpers.VSizeContainerOptHelper = function (elementSize) {
  this.writeOptional = function (os, tag, v) {
    if (v !== undefined && os.writeOptional(tag, OptionalFormat.VSize)) {
      var sz = this.size(v);
      os.writeSize(sz > 254 ? sz * elementSize + 5 : sz * elementSize + 1);
      this.write(os, v);
    }
  };

  this.readOptional = function (is, tag) {
    var v;

    if (is.readOptional(tag, OptionalFormat.VSize)) {
      is.skipSize();
      v = this.read(is);
    }

    return v;
  };
};

StreamHelpers.VSizeContainer1OptHelper = function () {
  this.writeOptional = function (os, tag, v) {
    if (v !== undefined && os.writeOptional(tag, OptionalFormat.VSize)) {
      this.write(os, v);
    }
  };

  this.readOptional = function (is, tag) {
    var v;

    if (is.readOptional(tag, OptionalFormat.VSize)) {
      v = this.read(is);
    }

    return v;
  };
}; //
// Sequence helper to write sequences
//


var SequenceHelper = /*#__PURE__*/function () {
  function SequenceHelper() {
    _classCallCheck(this, SequenceHelper);
  }

  _createClass(SequenceHelper, [{
    key: "write",
    value: function write(os, v) {
      if (v === null || v === undefined || v.length === 0) {
        os.writeSize(0);
      } else {
        var helper = this.elementHelper;
        os.writeSize(v.length);

        for (var i = 0; i < v.length; ++i) {
          helper.write(os, v[i]);
        }
      }
    }
  }, {
    key: "read",
    value: function read(is) {
      var helper = this.elementHelper; // Cache the element helper.

      var sz = is.readAndCheckSeqSize(helper.minWireSize);
      var v = [];
      v.length = sz;

      for (var i = 0; i < sz; ++i) {
        v[i] = helper.read(is);
      }

      return v;
    }
  }, {
    key: "size",
    value: function size(v) {
      return v === null || v === undefined ? 0 : v.length;
    }
  }, {
    key: "minWireSize",
    get: function get() {
      return 1;
    }
  }]);

  return SequenceHelper;
}(); // Speacialization optimized for ByteSeq


var byteSeqHelper = new SequenceHelper();

byteSeqHelper.write = function (os, v) {
  return os.writeByteSeq(v);
};

byteSeqHelper.read = function (is) {
  return is.readByteSeq();
};

defineProperty(byteSeqHelper, "elementHelper", {
  get: function get() {
    return Ice.ByteHelper;
  }
});
StreamHelpers.VSizeContainer1OptHelper.call(byteSeqHelper); // Read method for value sequences

var valueSequenceHelperRead = function valueSequenceHelperRead(is) {
  var sz = is.readAndCheckSeqSize(1);
  var v = [];
  v.length = sz;
  var elementType = this.elementType;

  var readValueAtIndex = function readValueAtIndex(idx) {
    is.readValue(function (obj) {
      v[idx] = obj;
    }, elementType);
  };

  for (var i = 0; i < sz; ++i) {
    readValueAtIndex(i);
  }

  return v;
};

StreamHelpers.generateSeqHelper = function (elementHelper, fixed, elementType) {
  if (elementHelper === Ice.ByteHelper) {
    return byteSeqHelper;
  }

  var helper = new SequenceHelper();

  if (fixed) {
    if (elementHelper.minWireSize === 1) {
      StreamHelpers.VSizeContainer1OptHelper.call(helper);
    } else {
      StreamHelpers.VSizeContainerOptHelper.call(helper, elementHelper.minWireSize);
    }
  } else {
    StreamHelpers.FSizeOptHelper.call(helper);
  }

  defineProperty(helper, "elementHelper", {
    get: function get() {
      return elementHelper;
    }
  });

  if (elementHelper == Ice.ObjectHelper) {
    defineProperty(helper, "elementType", {
      get: function get() {
        return elementType;
      }
    });
    helper.read = valueSequenceHelperRead;
  }

  return helper;
}; //
// Dictionary helper to write dictionaries
//


var DictionaryHelper = /*#__PURE__*/function () {
  function DictionaryHelper() {
    _classCallCheck(this, DictionaryHelper);
  }

  _createClass(DictionaryHelper, [{
    key: "write",
    value: function write(os, v) {
      if (v === null || v == undefined || v.size === 0) {
        os.writeSize(0);
      } else {
        var keyHelper = this.keyHelper;
        var valueHelper = this.valueHelper;
        os.writeSize(v.size);

        var _iterator = _createForOfIteratorHelper(v),
            _step;

        try {
          for (_iterator.s(); !(_step = _iterator.n()).done;) {
            var _step$value = _slicedToArray(_step.value, 2),
                key = _step$value[0],
                value = _step$value[1];

            keyHelper.write(os, key);
            valueHelper.write(os, value);
          }
        } catch (err) {
          _iterator.e(err);
        } finally {
          _iterator.f();
        }
      }
    }
  }, {
    key: "read",
    value: function read(is) {
      var mapType = this.mapType;
      var v = new mapType();
      var sz = is.readSize();
      var keyHelper = this.keyHelper;
      var valueHelper = this.valueHelper;

      for (var i = 0; i < sz; ++i) {
        v.set(keyHelper.read(is), valueHelper.read(is));
      }

      return v;
    }
  }, {
    key: "size",
    value: function size(v) {
      return v === null || v === undefined ? 0 : v.size;
    }
  }, {
    key: "minWireSize",
    get: function get() {
      return 1;
    }
  }]);

  return DictionaryHelper;
}(); // Read method for dictionaries of values


var valueDictionaryHelperRead = function valueDictionaryHelperRead(is) {
  var sz = is.readSize();
  var mapType = this.mapType;
  var v = new mapType();
  var valueType = this.valueType;

  var readValueForKey = function readValueForKey(key) {
    is.readValue(function (obj) {
      return v.set(key, obj);
    }, valueType);
  };

  var keyHelper = this.keyHelper;

  for (var i = 0; i < sz; ++i) {
    readValueForKey(keyHelper.read(is));
  }

  return v;
};

StreamHelpers.generateDictHelper = function (keyHelper, valueHelper, fixed, valueType, mapType) {
  var helper = new DictionaryHelper();

  if (fixed) {
    StreamHelpers.VSizeContainerOptHelper.call(helper, keyHelper.minWireSize + valueHelper.minWireSize);
  } else {
    StreamHelpers.FSizeOptHelper.call(helper);
  }

  defineProperty(helper, "mapType", {
    get: function get() {
      return mapType;
    }
  });
  defineProperty(helper, "keyHelper", {
    get: function get() {
      return keyHelper;
    }
  });
  defineProperty(helper, "valueHelper", {
    get: function get() {
      return valueHelper;
    }
  });

  if (valueHelper == Ice.ObjectHelper) {
    defineProperty(helper, "valueType", {
      get: function get() {
        return valueType;
      }
    });
    helper.read = valueDictionaryHelperRead;
  }

  return helper;
};

Ice.StreamHelpers = StreamHelpers;
module.exports.Ice = Ice;
